@@ -2,8 +2,8 @@ package Glib::Install::Files;
 
 $self = {
           'deps' => [],
-          'inc' => ' -I. -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -D_REENTRANT -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include',
-          'libs' => '-lgobject-2.0 -lglib-2.0 -lintl -lgthread-2.0 -lglib-2.0 -lintl',
+          'inc' => ' -I. -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -pthread -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include',
+          'libs' => '-lgobject-2.0 -lglib-2.0 -lintl -lgthread-2.0 -pthread -lglib-2.0 -lintl',
           'typemaps' => [
                           'typemap'
                         ]
